Class: Aws::SsmSap::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SsmSap::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ssmsap/client.rb,
sig/client.rbs
Overview
An API client for SsmSap. To construct a client, you need to configure a :region and :credentials.
client = Aws::SsmSap::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _DeleteResourcePermissionResponseSuccess, _DeregisterApplicationResponseSuccess, _GetApplicationResponseSuccess, _GetComponentResponseSuccess, _GetConfigurationCheckOperationResponseSuccess, _GetDatabaseResponseSuccess, _GetOperationResponseSuccess, _GetResourcePermissionResponseSuccess, _ListApplicationsResponseSuccess, _ListComponentsResponseSuccess, _ListConfigurationCheckDefinitionsResponseSuccess, _ListConfigurationCheckOperationsResponseSuccess, _ListDatabasesResponseSuccess, _ListOperationEventsResponseSuccess, _ListOperationsResponseSuccess, _ListSubCheckResultsResponseSuccess, _ListSubCheckRuleResultsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutResourcePermissionResponseSuccess, _RegisterApplicationResponseSuccess, _StartApplicationRefreshResponseSuccess, _StartApplicationResponseSuccess, _StartConfigurationChecksResponseSuccess, _StopApplicationResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateApplicationSettingsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_resource_permission(params = {}) ⇒ Types::DeleteResourcePermissionOutput
Removes permissions associated with the target database.
-
#deregister_application(params = {}) ⇒ Struct
Deregister an SAP application with AWS Systems Manager for SAP.
-
#get_application(params = {}) ⇒ Types::GetApplicationOutput
Gets an application registered with AWS Systems Manager for SAP.
-
#get_component(params = {}) ⇒ Types::GetComponentOutput
Gets the component of an application registered with AWS Systems Manager for SAP.
-
#get_configuration_check_operation(params = {}) ⇒ Types::GetConfigurationCheckOperationOutput
Gets the details of a configuration check operation by specifying the operation ID.
-
#get_database(params = {}) ⇒ Types::GetDatabaseOutput
Gets the SAP HANA database of an application registered with AWS Systems Manager for SAP.
-
#get_operation(params = {}) ⇒ Types::GetOperationOutput
Gets the details of an operation by specifying the operation ID.
-
#get_resource_permission(params = {}) ⇒ Types::GetResourcePermissionOutput
Gets permissions associated with the target database.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsOutput
Lists all the applications registered with AWS Systems Manager for SAP.
-
#list_components(params = {}) ⇒ Types::ListComponentsOutput
Lists all the components registered with AWS Systems Manager for SAP.
-
#list_configuration_check_definitions(params = {}) ⇒ Types::ListConfigurationCheckDefinitionsOutput
Lists all configuration check types supported by AWS Systems Manager for SAP.
-
#list_configuration_check_operations(params = {}) ⇒ Types::ListConfigurationCheckOperationsOutput
Lists the configuration check operations performed by AWS Systems Manager for SAP.
-
#list_databases(params = {}) ⇒ Types::ListDatabasesOutput
Lists the SAP HANA databases of an application registered with AWS Systems Manager for SAP.
-
#list_operation_events(params = {}) ⇒ Types::ListOperationEventsOutput
Returns a list of operations events.
-
#list_operations(params = {}) ⇒ Types::ListOperationsOutput
Lists the operations performed by AWS Systems Manager for SAP.
-
#list_sub_check_results(params = {}) ⇒ Types::ListSubCheckResultsOutput
Lists the sub-check results of a specified configuration check operation.
-
#list_sub_check_rule_results(params = {}) ⇒ Types::ListSubCheckRuleResultsOutput
Lists the rules of a specified sub-check belonging to a configuration check operation.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags on an SAP HANA application and/or database registered with AWS Systems Manager for SAP.
-
#put_resource_permission(params = {}) ⇒ Types::PutResourcePermissionOutput
Adds permissions to the target database.
-
#register_application(params = {}) ⇒ Types::RegisterApplicationOutput
Register an SAP application with AWS Systems Manager for SAP.
-
#start_application(params = {}) ⇒ Types::StartApplicationOutput
Request is an operation which starts an application.
-
#start_application_refresh(params = {}) ⇒ Types::StartApplicationRefreshOutput
Refreshes a registered application.
-
#start_configuration_checks(params = {}) ⇒ Types::StartConfigurationChecksOutput
Initiates configuration check operations against a specified application.
-
#stop_application(params = {}) ⇒ Types::StopApplicationOutput
Request is an operation to stop an application.
-
#tag_resource(params = {}) ⇒ Struct
Creates tag for a resource by specifying the ARN.
-
#untag_resource(params = {}) ⇒ Struct
Delete the tags for a resource.
-
#update_application_settings(params = {}) ⇒ Types::UpdateApplicationSettingsOutput
Updates the settings of an application registered with AWS Systems Manager for SAP.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-ssmsap/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1811 1812 1813 |
# File 'lib/aws-sdk-ssmsap/client.rb', line 1811 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1814 1815 1816 |
# File 'lib/aws-sdk-ssmsap/client.rb', line 1814 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 |
# File 'lib/aws-sdk-ssmsap/client.rb', line 1784 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SsmSap') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ssmsap' context[:gem_version] = '1.56.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_resource_permission(params = {}) ⇒ Types::DeleteResourcePermissionOutput
Removes permissions associated with the target database.
86 |
# File 'sig/client.rbs', line 86
def delete_resource_permission: (
|
#deregister_application(params = {}) ⇒ Struct
Deregister an SAP application with AWS Systems Manager for SAP. This action does not affect the existing setup of your SAP workloads on Amazon EC2.
97 |
# File 'sig/client.rbs', line 97
def deregister_application: (
|
#get_application(params = {}) ⇒ Types::GetApplicationOutput
Gets an application registered with AWS Systems Manager for SAP. It also returns the components of the application.
108 |
# File 'sig/client.rbs', line 108
def get_application: (
|
#get_component(params = {}) ⇒ Types::GetComponentOutput
Gets the component of an application registered with AWS Systems Manager for SAP.
121 |
# File 'sig/client.rbs', line 121
def get_component: (
|
#get_configuration_check_operation(params = {}) ⇒ Types::GetConfigurationCheckOperationOutput
Gets the details of a configuration check operation by specifying the operation ID.
132 |
# File 'sig/client.rbs', line 132
def get_configuration_check_operation: (
|
#get_database(params = {}) ⇒ Types::GetDatabaseOutput
Gets the SAP HANA database of an application registered with AWS Systems Manager for SAP.
143 |
# File 'sig/client.rbs', line 143
def get_database: (
|
#get_operation(params = {}) ⇒ Types::GetOperationOutput
Gets the details of an operation by specifying the operation ID.
156 |
# File 'sig/client.rbs', line 156
def get_operation: (
|
#get_resource_permission(params = {}) ⇒ Types::GetResourcePermissionOutput
Gets permissions associated with the target database.
166 |
# File 'sig/client.rbs', line 166
def get_resource_permission: (
|
#list_applications(params = {}) ⇒ Types::ListApplicationsOutput
Lists all the applications registered with AWS Systems Manager for SAP.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
178 |
# File 'sig/client.rbs', line 178
def list_applications: (
|
#list_components(params = {}) ⇒ Types::ListComponentsOutput
Lists all the components registered with AWS Systems Manager for SAP.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
197 |
# File 'sig/client.rbs', line 197
def list_components: (
|
#list_configuration_check_definitions(params = {}) ⇒ Types::ListConfigurationCheckDefinitionsOutput
Lists all configuration check types supported by AWS Systems Manager for SAP.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
210 |
# File 'sig/client.rbs', line 210
def list_configuration_check_definitions: (
|
#list_configuration_check_operations(params = {}) ⇒ Types::ListConfigurationCheckOperationsOutput
Lists the configuration check operations performed by AWS Systems Manager for SAP.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
222 |
# File 'sig/client.rbs', line 222
def list_configuration_check_operations: (
|
#list_databases(params = {}) ⇒ Types::ListDatabasesOutput
Lists the SAP HANA databases of an application registered with AWS Systems Manager for SAP.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
243 |
# File 'sig/client.rbs', line 243
def list_databases: (
|
#list_operation_events(params = {}) ⇒ Types::ListOperationEventsOutput
Returns a list of operations events.
Available parameters include OperationID, as well as optional
parameters MaxResults, NextToken, and Filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
257 |
# File 'sig/client.rbs', line 257
def list_operation_events: (
|
#list_operations(params = {}) ⇒ Types::ListOperationsOutput
Lists the operations performed by AWS Systems Manager for SAP.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
277 |
# File 'sig/client.rbs', line 277
def list_operations: (
|
#list_sub_check_results(params = {}) ⇒ Types::ListSubCheckResultsOutput
Lists the sub-check results of a specified configuration check operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
297 |
# File 'sig/client.rbs', line 297
def list_sub_check_results: (
|
#list_sub_check_rule_results(params = {}) ⇒ Types::ListSubCheckRuleResultsOutput
Lists the rules of a specified sub-check belonging to a configuration check operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
310 |
# File 'sig/client.rbs', line 310
def list_sub_check_rule_results: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags on an SAP HANA application and/or database registered with AWS Systems Manager for SAP.
322 |
# File 'sig/client.rbs', line 322
def list_tags_for_resource: (
|
#put_resource_permission(params = {}) ⇒ Types::PutResourcePermissionOutput
Adds permissions to the target database.
332 |
# File 'sig/client.rbs', line 332
def put_resource_permission: (
|
#register_application(params = {}) ⇒ Types::RegisterApplicationOutput
Register an SAP application with AWS Systems Manager for SAP. You must meet the following requirements before registering.
The SAP application you want to register with AWS Systems Manager for SAP is running on Amazon EC2.
AWS Systems Manager Agent must be setup on an Amazon EC2 instance along with the required IAM permissions.
Amazon EC2 instance(s) must have access to the secrets created in AWS Secrets Manager to manage SAP applications and components.
345 |
# File 'sig/client.rbs', line 345
def register_application: (
|
#start_application(params = {}) ⇒ Types::StartApplicationOutput
Request is an operation which starts an application.
Parameter ApplicationId is required.
375 |
# File 'sig/client.rbs', line 375
def start_application: (
|
#start_application_refresh(params = {}) ⇒ Types::StartApplicationRefreshOutput
Refreshes a registered application.
385 |
# File 'sig/client.rbs', line 385
def start_application_refresh: (
|
#start_configuration_checks(params = {}) ⇒ Types::StartConfigurationChecksOutput
Initiates configuration check operations against a specified application.
395 |
# File 'sig/client.rbs', line 395
def start_configuration_checks: (
|
#stop_application(params = {}) ⇒ Types::StopApplicationOutput
Request is an operation to stop an application.
Parameter ApplicationId is required. Parameters
StopConnectedEntity and IncludeEc2InstanceShutdown are optional.
406 |
# File 'sig/client.rbs', line 406
def stop_application: (
|
#tag_resource(params = {}) ⇒ Struct
Creates tag for a resource by specifying the ARN.
417 |
# File 'sig/client.rbs', line 417
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Delete the tags for a resource.
427 |
# File 'sig/client.rbs', line 427
def untag_resource: (
|
#update_application_settings(params = {}) ⇒ Types::UpdateApplicationSettingsOutput
Updates the settings of an application registered with AWS Systems Manager for SAP.
439 |
# File 'sig/client.rbs', line 439
def update_application_settings: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1804 1805 1806 |
# File 'lib/aws-sdk-ssmsap/client.rb', line 1804 def waiter_names [] end |