Class: Aws::SsmSap::Types::Component

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmsap/types.rb

Overview

The SAP component of your application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The ID of the application.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#associated_hostTypes::AssociatedHost

The associated host of the component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#child_componentsArray<String>

The child components of a highly available environment. For example, in a highly available SAP on AWS workload, the child component consists of the primary and secondar instances.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#component_idString

The ID of the component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#component_typeString

The type of the component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#database_connectionTypes::DatabaseConnection

The connection specifications for the database of the component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#databasesArray<String>

The SAP HANA databases of the component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#hdb_versionString

The SAP HANA version of the component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#hostsArray<Types::Host>

The hosts of the component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#last_updatedTime

The time at which the component was last updated.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#parent_componentString

The parent component of a highly available environment. For example, in a highly available SAP on AWS workload, the parent component consists of the entire setup, including the child components.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#primary_hostString

The primary host of the component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#resilienceTypes::Resilience

Details of the SAP HANA system replication for the component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#sap_featureString

The SAP feature of the component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#sap_hostnameString

The hostname of the component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#sap_kernel_versionString

The kernel version of the component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#sidString

The SAP System Identifier of the application component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the component.

  • ACTIVATED - this status has been deprecated.

  • STARTING - the component is in the process of being started.

  • STOPPED - the component is not running.

  • STOPPING - the component is in the process of being stopped.

  • RUNNING - the component is running.

  • RUNNING_WITH_ERROR - one or more child component(s) of the parent component is not running. Call GetComponent to review the status of each child component.

  • UNDEFINED - AWS Systems Manager for SAP cannot provide the component status based on the discovered information. Verify your SAP application.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#system_numberString

The SAP system number of the application component.

Returns:



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-ssmsap/types.rb', line 291

class Component < Struct.new(
  :component_id,
  :sid,
  :system_number,
  :parent_component,
  :child_components,
  :application_id,
  :component_type,
  :status,
  :sap_hostname,
  :sap_feature,
  :sap_kernel_version,
  :hdb_version,
  :resilience,
  :associated_host,
  :databases,
  :hosts,
  :primary_host,
  :database_connection,
  :last_updated,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end