Class: Aws::SsmSap::Types::ListConfigurationCheckOperationsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmsap/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The ID of the application.



1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-ssmsap/types.rb', line 1128

class ListConfigurationCheckOperationsInput < Struct.new(
  :application_id,
  :list_mode,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

The filters of an operation.



1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-ssmsap/types.rb', line 1128

class ListConfigurationCheckOperationsInput < Struct.new(
  :application_id,
  :list_mode,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#list_modeString

The mode for listing configuration check operations. Defaults to “LATEST_PER_CHECK”.

  • LATEST_PER_CHECK - Will list the latest configuration check operation per check type.

  • ALL_OPERATIONS - Will list all configuration check operations performed on the application.



1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-ssmsap/types.rb', line 1128

class ListConfigurationCheckOperationsInput < Struct.new(
  :application_id,
  :list_mode,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.



1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-ssmsap/types.rb', line 1128

class ListConfigurationCheckOperationsInput < Struct.new(
  :application_id,
  :list_mode,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next page of results.



1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-ssmsap/types.rb', line 1128

class ListConfigurationCheckOperationsInput < Struct.new(
  :application_id,
  :list_mode,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end